@@ -43,7 +43,12 @@
 
 hy_sed_daily_loads <- function(station_number = NULL,
                                hydat_path = NULL,
-                               prov_terr_state_loc = NULL, start_date ="ALL", end_date = "ALL") {
+                               prov_terr_state_loc = NULL,                       
+                               start_date = NULL, 
+                               end_date = NULL) {
+  
+  ## Determine which dates should be queried
+  dates_null <- date_check(start_date, end_date)
 
   ## Read in database
   hydat_con <- hy_src(hydat_path)
@@ -51,32 +56,6 @@ hy_sed_daily_loads <- function(station_number = NULL,
     on.exit(hy_src_disconnect(hydat_con))
   }
 
-  if (start_date == "ALL" & end_date == "ALL") {
-    message("No start and end dates specified. All dates available will be returned.")
-  } else {
-    ## When we want date contraints we need to break apart the dates because SQL has no native date format
-    ## Start
-    start_year <- lubridate::year(start_date)
-    start_month <- lubridate::month(start_date)
-    start_day <- lubridate::day(start_date)
-
-    ## End
-    end_year <- lubridate::year(end_date)
-    end_month <- lubridate::month(end_date)
-    end_day <- lubridate::day(end_date)
-  }
-
-  ## Check date is in the right format
-  if (start_date != "ALL" | end_date != "ALL") {
-    if (is.na(as.Date(start_date, format = "%Y-%m-%d")) | is.na(as.Date(end_date, format = "%Y-%m-%d"))) {
-      stop("Invalid date format. Dates need to be in YYYY-MM-DD format")
-    }
-
-    if (start_date > end_date) {
-      stop("start_date is after end_date. Try swapping values.")
-    }
-  }
-
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
 
@@ -92,10 +71,10 @@ hy_sed_daily_loads <- function(station_number = NULL,
   sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_STATION_NUMBER %in% stns)
 
   ## Do the initial subset to take advantage of dbplyr only issuing sql query when it has too
-  if (start_date != "ALL" | end_date != "ALL") {
-    sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_YEAR >= start_year &
-      !!sym_YEAR <= end_year)
-  }
+  
+  ## by year
+  if (!dates_null[["start_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_YEAR >= lubridate::year(start_date))
+  if (!dates_null[["end_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_YEAR <= lubridate::year(end_date))
 
   sed_dly_loads <- dplyr::select(
     sed_dly_loads, .data$STATION_NUMBER, .data$YEAR, .data$MONTH,
@@ -121,10 +100,8 @@ hy_sed_daily_loads <- function(station_number = NULL,
   ))
 
   ## Then when a date column exist fine tune the subset
-  if (start_date != "ALL" | end_date != "ALL") {
-    sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date >= start_date &
-                                     !!sym_Date <= end_date)
-  }
+  if (!dates_null[["start_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date >= start_date)
+  if (!dates_null[["end_is_null"]]) sed_dly_loads <- dplyr::filter(sed_dly_loads, !!sym_Date <= end_date)
 
   sed_dly_loads <- dplyr::mutate(sed_dly_loads, Parameter = "Load")
   sed_dly_loads <- dplyr::select(sed_dly_loads, .data$STATION_NUMBER, .data$Date, .data$Parameter, .data$LOAD)
