@@ -25,8 +25,8 @@
 #' @format A tibble with 5 variables:
 #' \describe{
 #'   \item{STATION_NUMBER}{Unique 7 digit Water Survey of Canada station number}
-#'   \item{SED_DATA_TYPE_EN}{Contains the type of sampling method used in collecting sediment for a station}
-#'   \item{DATE}{Contains the time to the nearest minute of when the sample was taken}
+#'   \item{SED_DATA_TYPE}{Contains the type of sampling method used in collecting sediment for a station}
+#'   \item{Date}{Contains the time to the nearest minute of when the sample was taken}
 #'   \item{PARTICLE_SIZE}{Particle size (mm)}
 #'   \item{PERCENT}{Contains the percentage values for indicated particle sizes for samples collected}
 #' }
@@ -45,7 +45,12 @@
 
 hy_sed_samples_psd <- function(station_number = NULL,
                             hydat_path = NULL, 
-                            prov_terr_state_loc = NULL, start_date ="ALL", end_date = "ALL") {
+                            prov_terr_state_loc = NULL, 
+                            start_date =NULL, 
+                            end_date = NULL) {
+  
+  ## Determine which dates should be queried
+  dates_null <- date_check(start_date, end_date)
   
   ## Read in database
   hydat_con <- hy_src(hydat_path)
@@ -53,32 +58,6 @@ hy_sed_samples_psd <- function(station_number = NULL,
     on.exit(hy_src_disconnect(hydat_con))
   }
   
-  if (start_date == "ALL" & end_date == "ALL") {
-    message("No start and end dates specified. All dates available will be returned.")
-  } else {
-    ## When we want date contraints we need to break apart the dates because SQL has no native date format
-    ## Start
-    start_year <- lubridate::year(start_date)
-    start_month <- lubridate::month(start_date)
-    start_day <- lubridate::day(start_date)
-
-    ## End
-    end_year <- lubridate::year(end_date)
-    end_month <- lubridate::month(end_date)
-    end_day <- lubridate::day(end_date)
-  }
-
-  ## Check date is in the right format
-  if (start_date != "ALL" | end_date != "ALL") {
-    if (is.na(as.Date(start_date, format = "%Y-%m-%d")) | is.na(as.Date(end_date, format = "%Y-%m-%d"))) {
-      stop("Invalid date format. Dates need to be in YYYY-MM-DD format")
-    }
-
-    if (start_date > end_date) {
-      stop("start_date is after end_date. Try swapping values.")
-    }
-  }
-
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
   
@@ -93,20 +72,18 @@ hy_sed_samples_psd <- function(station_number = NULL,
 
   sed_samples_psd <- dplyr::collect(sed_samples_psd)
   
-  if(is.data.frame(sed_samples_psd) && nrow(sed_samples_psd)==0)
-  {stop("This station is not present in HYDAT")}
+  if(is.data.frame(sed_samples_psd) && nrow(sed_samples_psd)==0) stop("This station is not present in HYDAT")
+  
+  sed_samples_psd <- dplyr::mutate(sed_samples_psd, DATE = lubridate::ymd_hms(.data$DATE), date_no_time = as.Date(.data$DATE))
   
-  sed_samples_psd <- dplyr::mutate(sed_samples_psd, DATE = lubridate::ymd_hms(.data$DATE))
-
   ## SUBSET by date
-  if (start_date != "ALL" | end_date != "ALL") {
-    sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym_DATE >= start_date &
-      !!sym_DATE <= end_date)
-  }
+  if (!dates_null[["start_is_null"]]) sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym("date_no_time") >= as.Date(start_date))
+  if (!dates_null[["end_is_null"]]) sed_samples_psd <- dplyr::filter(sed_samples_psd, !!sym("date_no_time") <= as.Date(end_date))
   
   
-  sed_samples_psd <- dplyr::select(sed_samples_psd, .data$STATION_NUMBER, .data$SED_DATA_TYPE_EN, .data$DATE,
-                                   .data$PARTICLE_SIZE, .data$PERCENT)
+  sed_samples_psd <- dplyr::select(sed_samples_psd, .data$STATION_NUMBER, 
+                                   SED_DATA_TYPE = .data$SED_DATA_TYPE_EN, 
+                                   Date = .data$DATE, .data$PARTICLE_SIZE, .data$PERCENT)
   
   
   ## What stations were missed?
