@@ -82,25 +82,28 @@ hy_stations <- function(station_number = NULL,
 
   ## Determine which stations we are querying
   stns <- station_choice(hydat_con, station_number, prov_terr_state_loc)
+  
+  ## Creating rlang symbols
+  sym_STATION_NUMBER <- sym("STATION_NUMBER")
 
   ## Create the dataframe to return
-  df <- dplyr::tbl(hydat_con, dbplyr::sql("SELECT * FROM `STATIONS`")) %>%
-    dplyr::filter(STATION_NUMBER %in% stns) %>%
+  df <- dplyr::tbl(hydat_con, "STATIONS") %>%
+    dplyr::filter(!!sym_STATION_NUMBER %in% stns) %>%
     dplyr::collect() %>%
-    dplyr::mutate(REGIONAL_OFFICE_ID = as.numeric(REGIONAL_OFFICE_ID)) %>%
+    dplyr::mutate(REGIONAL_OFFICE_ID = as.numeric(.data$REGIONAL_OFFICE_ID)) %>%
     dplyr::mutate(
       HYD_STATUS = dplyr::case_when(
-        HYD_STATUS == "D" ~ "DISCONTINUED",
-        HYD_STATUS == "A" ~ "ACTIVE",
+        .data$HYD_STATUS == "D" ~ "DISCONTINUED",
+        .data$HYD_STATUS == "A" ~ "ACTIVE",
         TRUE ~ "NA"
       ),
       SED_STATUS = dplyr::case_when(
-        SED_STATUS == "D" ~ "DISCONTINUED",
-        SED_STATUS == "A" ~ "ACTIVE",
+        .data$SED_STATUS == "D" ~ "DISCONTINUED",
+        .data$SED_STATUS == "A" ~ "ACTIVE",
         TRUE ~ "NA"
       ),
-      RHBN = RHBN == 1,
-      REAL_TIME = REAL_TIME == 1
+      RHBN = .data$RHBN == 1,
+      REAL_TIME = .data$REAL_TIME == 1
     )
 
   ## What stations were missed?
